emoji\_data package
===================

Submodules
----------

.. toctree::

   emoji_data.character
   emoji_data.sequence
   emoji_data.utils
   emoji_data.version

Module contents
---------------

.. automodule:: emoji_data
    :members:
    :undoc-members:
    :show-inheritance:
